@@ -3,9 +3,9 @@ Main interface for qldb service type definitions.
 
 Usage::
 
-    from mypy_boto3.qldb.type_defs import CreateLedgerResponseTypeDef
+    from mypy_boto3.qldb.type_defs import CancelJournalKinesisStreamResponseTypeDef
 
-    data: CreateLedgerResponseTypeDef = {...}
+    data: CancelJournalKinesisStreamResponseTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,7 +22,11 @@ else:
 
 
 __all__ = (
+    "CancelJournalKinesisStreamResponseTypeDef",
     "CreateLedgerResponseTypeDef",
+    "KinesisConfigurationTypeDef",
+    "JournalKinesisStreamDescriptionTypeDef",
+    "DescribeJournalKinesisStreamResponseTypeDef",
     "S3EncryptionConfigurationTypeDef",
     "S3ExportConfigurationTypeDef",
     "JournalS3ExportDescriptionTypeDef",
@@ -33,14 +37,20 @@ __all__ = (
     "GetBlockResponseTypeDef",
     "GetDigestResponseTypeDef",
     "GetRevisionResponseTypeDef",
+    "ListJournalKinesisStreamsForLedgerResponseTypeDef",
     "ListJournalS3ExportsForLedgerResponseTypeDef",
     "ListJournalS3ExportsResponseTypeDef",
     "LedgerSummaryTypeDef",
     "ListLedgersResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "StreamJournalToKinesisResponseTypeDef",
     "UpdateLedgerResponseTypeDef",
 )
 
+CancelJournalKinesisStreamResponseTypeDef = TypedDict(
+    "CancelJournalKinesisStreamResponseTypeDef", {"StreamId": str}, total=False
+)
+
 CreateLedgerResponseTypeDef = TypedDict(
     "CreateLedgerResponseTypeDef",
     {
@@ -53,6 +63,56 @@ CreateLedgerResponseTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredKinesisConfigurationTypeDef = TypedDict(
+    "_RequiredKinesisConfigurationTypeDef", {"StreamArn": str}
+)
+_OptionalKinesisConfigurationTypeDef = TypedDict(
+    "_OptionalKinesisConfigurationTypeDef", {"AggregationEnabled": bool}, total=False
+)
+
+
+class KinesisConfigurationTypeDef(
+    _RequiredKinesisConfigurationTypeDef, _OptionalKinesisConfigurationTypeDef
+):
+    pass
+
+
+_RequiredJournalKinesisStreamDescriptionTypeDef = TypedDict(
+    "_RequiredJournalKinesisStreamDescriptionTypeDef",
+    {
+        "LedgerName": str,
+        "RoleArn": str,
+        "StreamId": str,
+        "Status": Literal["ACTIVE", "COMPLETED", "CANCELED", "FAILED", "IMPAIRED"],
+        "KinesisConfiguration": KinesisConfigurationTypeDef,
+        "StreamName": str,
+    },
+)
+_OptionalJournalKinesisStreamDescriptionTypeDef = TypedDict(
+    "_OptionalJournalKinesisStreamDescriptionTypeDef",
+    {
+        "CreationTime": datetime,
+        "InclusiveStartTime": datetime,
+        "ExclusiveEndTime": datetime,
+        "Arn": str,
+        "ErrorCause": Literal["KINESIS_STREAM_NOT_FOUND", "IAM_PERMISSION_REVOKED"],
+    },
+    total=False,
+)
+
+
+class JournalKinesisStreamDescriptionTypeDef(
+    _RequiredJournalKinesisStreamDescriptionTypeDef, _OptionalJournalKinesisStreamDescriptionTypeDef
+):
+    pass
+
+
+DescribeJournalKinesisStreamResponseTypeDef = TypedDict(
+    "DescribeJournalKinesisStreamResponseTypeDef",
+    {"Stream": JournalKinesisStreamDescriptionTypeDef},
+    total=False,
+)
+
 _RequiredS3EncryptionConfigurationTypeDef = TypedDict(
     "_RequiredS3EncryptionConfigurationTypeDef",
     {"ObjectEncryptionType": Literal["SSE_KMS", "SSE_S3", "NO_ENCRYPTION"]},
@@ -138,6 +198,12 @@ class GetRevisionResponseTypeDef(
     pass
 
 
+ListJournalKinesisStreamsForLedgerResponseTypeDef = TypedDict(
+    "ListJournalKinesisStreamsForLedgerResponseTypeDef",
+    {"Streams": List[JournalKinesisStreamDescriptionTypeDef], "NextToken": str},
+    total=False,
+)
+
 ListJournalS3ExportsForLedgerResponseTypeDef = TypedDict(
     "ListJournalS3ExportsForLedgerResponseTypeDef",
     {"JournalS3Exports": List[JournalS3ExportDescriptionTypeDef], "NextToken": str},
@@ -170,6 +236,10 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
 )
 
+StreamJournalToKinesisResponseTypeDef = TypedDict(
+    "StreamJournalToKinesisResponseTypeDef", {"StreamId": str}, total=False
+)
+
 UpdateLedgerResponseTypeDef = TypedDict(
     "UpdateLedgerResponseTypeDef",
     {
